@@ -2,20 +2,24 @@
 DBSession = None
 DeclarativeBase = None
 metadata = None
+User=None
+Group=None
 
-def init_stroller_model(app_DBSession, app_DeclarativeBase):
-    global DBSession, DeclarativeBase, metadata
+def init_stroller_model(app_DBSession, app_DeclarativeBase, app_User, app_Group):
+    global DBSession, DeclarativeBase, metadata, User, Group
     
     DBSession = app_DBSession
     DeclarativeBase = app_DeclarativeBase
     metadata = app_DeclarativeBase.metadata
+    User=app_User
+    Group=app_Group
     
     from commerce import Product, Category, Order, OrderItem, ProductInfo
     return Product, ProductInfo, Category, Order, OrderItem
     
 def setup_stroller_database(app_DBSession, app_DeclarativeBase,
                              User, Group):                         
-    init_stroller_model(app_DBSession, app_DeclarativeBase)
+    init_stroller_model(app_DBSession, app_DeclarativeBase, User, Group)
     from commerce import Product, Category, Order, OrderItem, ProductInfo
 
     g = Group()
